@@ -1,10 +1,10 @@
 /*
  * vim: softtabstop=4 shiftwidth=4 cindent foldmethod=marker expandtab
  *
- * $LastChangedDate: 2010-09-11 13:41:41 -0600 (Sat, 11 Sep 2010) $
- * $Revision: 1094 $
+ * $LastChangedDate: 2012-05-27 15:15:00 -0600 (Sun, 27 May 2012) $
+ * $Revision: 1173 $
  * $LastChangedBy: econnell $
- * $URL: http://svn.mangler.org/mangler/tags/1.2.2/jukebox/jukebox.c $
+ * $URL: http://svn.mangler.org/mangler/trunk/jukebox/jukebox.c $
  *
  * Copyright 2009-2010 Eric Connell
  *
@@ -53,6 +53,7 @@
  *                             ^~~~^~~~^                          *
  *                                                                *
  ******************************************************************
+  oh god this still exists :(
  */
 
 #define _GNU_SOURCE
@@ -82,7 +83,7 @@ static const char vorbis_title[] = "TITLE=";
 static const char vorbis_album[] = "ALBUM=";
 
 typedef struct {
-    int16_t  buf[1 << 15];
+    int16_t  buf[32768];
     uint32_t len;
 } pcm_data_t;
 
@@ -198,7 +199,7 @@ void ctrl_c(int signum) {
 }
 
 void usage(char *argv[]) {
-    fprintf(stderr, "usage: %s -h hostname:port -u username [-p password] [-c channelid] [-v volume_multipler] [-s disable stereo for celt] [-n don't shuffle] /path/to/music\n", argv[0]);
+    fprintf(stderr, "usage: %s -h hostname:port -u username [-p password] [-c channelid] [-v volume_multipler] [-s disable stereo for opus] [-n don't shuffle] /path/to/music\n", argv[0]);
     exit(EXIT_FAILURE);
 }
 
@@ -957,7 +958,7 @@ void *open_file(musicfile *musicfile, const v3_codec *codec) {
 }
 
 int get_pcm_frame(musicfile *musicfile, int channels, int16_t *buf, int *pcmread) {
-    unsigned char readbuffer[1 << 16];
+    unsigned char readbuffer[65536];
     int16_t *readptr;
     size_t numdecoded;
     int err;
@@ -991,7 +992,7 @@ int get_pcm_frame(musicfile *musicfile, int channels, int16_t *buf, int *pcmread
         if (pcmd.len < channels**pcmread) {
             pcmd.len = 0;
         } else {
-            memmove(pcmd.buf, (void *)pcmd.buf + channels**pcmread, sizeof(pcmd.buf) - channels**pcmread);
+            memmove(pcmd.buf, (void *)pcmd.buf + channels**pcmread, pcmd.len - channels**pcmread);
             pcmd.len -= channels**pcmread;
         }
         return true;
@@ -1029,7 +1030,7 @@ int get_pcm_frame(musicfile *musicfile, int channels, int16_t *buf, int *pcmread
             return false;
         }
         readptr = (int16_t *)readbuffer;
-        if (channels == 1) { // no channels to mix; this is for celt stereo mode
+        if (channels == 1) { // no channels to mix; this is for opus stereo mode
             memcpy(buf, readbuffer, *pcmread);
         } else for (ctr = 0; ctr < *pcmread/2; ctr++) {
             buf[ctr] = (readptr[ctr*2] + readptr[ctr*2+1]) / 2;
@@ -1235,7 +1236,7 @@ main(int argc, char **argv) {
         fprintf(stderr, "not shuffling musiclist\n");
     }
     if (!disable_stereo) {
-        fprintf(stderr, "will use 2 channels for the CELT codec\n");
+        fprintf(stderr, "will use 2 channels for the Opus codec (replacing channel codecs truespeech and lernout & hauspie)\n");
     }
     if (debug >= 2) {
         v3_debuglevel(V3_DEBUG_ALL);
