@@ -1,12 +1,12 @@
 /*
  * vim: softtabstop=4 shiftwidth=4 cindent foldmethod=marker expandtab
  *
- * $LastChangedDate: 2010-12-27 08:54:43 -0700 (Mon, 27 Dec 2010) $
- * $Revision: 1116 $
- * $LastChangedBy: clearscreen $
- * $URL: http://svn.mangler.org/mangler/tags/1.2.2/libventrilo3/libventrilo3.h $
+ * $LastChangedDate: 2012-05-24 12:01:51 -0600 (Thu, 24 May 2012) $
+ * $Revision: 1166 $
+ * $LastChangedBy: Haxar $
+ * $URL: http://svn.mangler.org/mangler/trunk/libventrilo3/libventrilo3.h $
  *
- * Copyright 2009-2010 Eric Connell
+ * Copyright 2009-2011 Eric Connell
  *
  * This file is part of Mangler.
  *
@@ -40,11 +40,12 @@
 
 #ifndef _WIN32
 #include <sys/time.h>
+#include <sys/select.h>
 #include <sys/socket.h>
 #include <netinet/in.h>
+#include <netinet/tcp.h>
 #include <arpa/inet.h>
 #include <netdb.h>
-#include <sys/select.h>
 #include <errno.h>
 #else
 #include <winsock2.h>
@@ -409,9 +410,9 @@ v3_codec v3_codecs[] = {
     { 0, 2, 640, 22050, -1, "GSM 6.10 22kHz" },
     { 0, 3, 640, 44100, -1, "GSM 6.10 44kHz" },
 #endif
-#if HAVE_CELT
-    { 1, 0, 640, 44100, -1, "CELT 0.7 44kHz" },
-    { 2, 0, 640, 22050, -1, "CELT 0.7 22kHz" },
+#if HAVE_OPUS
+    { 1, 0, 960*2, 48000, -1, "Opus 48kHz" },
+    { 2, 0, 960*2, 48000, -1, "Opus 48kHz" },
 #endif
 #if HAVE_SPEEX
     { 3, 0, 320, 8000, 0, "Speex 8kHz Quality 0" },
@@ -455,13 +456,14 @@ typedef struct __v3_decoders {
 #if HAVE_GSM
     void *gsm;
 #endif
+#if HAVE_SPEEX
     uint32_t speexrate;
     void *speex;
-#if HAVE_CELT
-    uint8_t celtchans;
-    void *celtmode;
-    void *celt;
 #endif
+#if HAVE_OPUS
+    void *opus;
+#endif
+    int _pad_;
 } _v3_decoders;
 
 _v3_decoders v3_decoders[65535];
@@ -698,7 +700,7 @@ v3_event                *_v3_create_event(uint16_t event);
 
 #ifdef _WIN32
 // TODO: May want to move these function definitions to a windows specific header file.
-int 					mingw_inet_aton(const char *cp, struct in_addr *addr);
+int                     mingw_inet_aton(const char *cp, struct in_addr *addr);
 #endif
 
 #if HAVE_SPEEX_DSP
@@ -717,9 +719,7 @@ uint8_t *_v3_audio_encode(
                 const v3_codec *codec,
                 uint16_t *datalen,
                 /* optional args */
-                uint8_t channels,
-                uint16_t *framecount,
-                uint8_t *celtfragsize);
+                uint8_t channels);
 int _v3_audio_decode(
                 /* encoded input */
                 const v3_codec *codec,
@@ -730,7 +730,7 @@ int _v3_audio_decode(
                 uint8_t *sample,
                 uint32_t *pcmlen,
                 /* optional args */
-                uint8_t channels);
+                uint8_t *channels);
 
 #endif // _LIBVENTRILO3_H
 
