@@ -1,12 +1,12 @@
 /*
  * vim: softtabstop=4 shiftwidth=4 cindent foldmethod=marker expandtab
  *
- * $LastChangedDate: 2011-04-09 21:13:40 -0600 (Sat, 09 Apr 2011) $
- * $Revision: 1119 $
- * $LastChangedBy: econnell $
- * $URL: http://svn.mangler.org/mangler/tags/1.2.2/src/manglersettings.cpp $
+ * $LastChangedDate: 2012-05-24 12:01:28 -0600 (Thu, 24 May 2012) $
+ * $Revision: 1160 $
+ * $LastChangedBy: Haxar $
+ * $URL: http://svn.mangler.org/mangler/trunk/src/manglersettings.cpp $
  *
- * Copyright 2009-2010 Eric Connell
+ * Copyright 2009-2011 Eric Connell
  *
  * This file is part of Mangler.
  *
@@ -341,9 +341,7 @@ void ManglerSettings::applySettings(void) {/*{{{*/
 
     // Input Gain
     Mangler::config["InputGainLevel"] = gainAdjustment->get_value();
-    fprintf(stderr, "setting gain to %d", Mangler::config["InputGainLevel"].toInt());
     v3_set_volume_xmit(Mangler::config["InputGainLevel"].toInt());
-    mangler->setTooltip();
 
     // Notification Sounds
     builder->get_widget("notificationLoginLogoutCheckButton", checkbutton);
@@ -839,7 +837,7 @@ ManglerSettings::settingsPTTMouseDetect(void) {/*{{{*/
     char mousebutton[8];
     static bool grabbed = false;
     int flag = 0;
-    int x, y;
+    //int x, y;
     XEvent ev;
 
 
@@ -865,8 +863,8 @@ ManglerSettings::settingsPTTMouseDetect(void) {/*{{{*/
                 XUngrabPointer(GDK_WINDOW_XDISPLAY(rootwin), CurrentTime);
                 grabbed = false;
                 isDetectingMouse = false;
-                x = ev.xbutton.x_root;
-                y = ev.xbutton.y_root;
+                //x = ev.xbutton.x_root;
+                //y = ev.xbutton.y_root;
                 break;
             case MotionNotify:
                 break;
